==> kdepimlibs-4.8.5-i486-1.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libmicroblog.so.4 )
( cd usr/lib ; ln -sf libmicroblog.so.4.8.0 libmicroblog.so.4 )
( cd usr/lib ; rm -rf libktnef.so.4 )
( cd usr/lib ; ln -sf libktnef.so.4.8.0 libktnef.so.4 )
( cd usr/lib ; rm -rf libkalarmcal.so )
( cd usr/lib ; ln -sf libkalarmcal.so.2 libkalarmcal.so )
( cd usr/lib ; rm -rf libqgpgme.so )
( cd usr/lib ; ln -sf libqgpgme.so.1 libqgpgme.so )
( cd usr/lib ; rm -rf libkimap.so.4 )
( cd usr/lib ; ln -sf libkimap.so.4.8.0 libkimap.so.4 )
( cd usr/lib ; rm -rf libakonadi-kmime.so.4 )
( cd usr/lib ; ln -sf libakonadi-kmime.so.4.8.0 libakonadi-kmime.so.4 )
( cd usr/lib ; rm -rf libkblog.so.4 )
( cd usr/lib ; ln -sf libkblog.so.4.8.0 libkblog.so.4 )
( cd usr/lib ; rm -rf libakonadi-kde.so.4 )
( cd usr/lib ; ln -sf libakonadi-kde.so.4.8.0 libakonadi-kde.so.4 )
( cd usr/lib ; rm -rf libakonadi-calendar.so )
( cd usr/lib ; ln -sf libakonadi-calendar.so.4 libakonadi-calendar.so )
( cd usr/lib ; rm -rf libakonadi-contact.so.4 )
( cd usr/lib ; ln -sf libakonadi-contact.so.4.8.0 libakonadi-contact.so.4 )
( cd usr/lib ; rm -rf libkpimtextedit.so.4 )
( cd usr/lib ; ln -sf libkpimtextedit.so.4.8.0 libkpimtextedit.so.4 )
( cd usr/lib ; rm -rf libgpgme++.so )
( cd usr/lib ; ln -sf libgpgme++.so.2 libgpgme++.so )
( cd usr/lib ; rm -rf libkabc_file_core.so )
( cd usr/lib ; ln -sf libkabc_file_core.so.4 libkabc_file_core.so )
( cd usr/lib ; rm -rf libkcalutils.so )
( cd usr/lib ; ln -sf libkcalutils.so.4 libkcalutils.so )
( cd usr/lib ; rm -rf libakonadi-calendar.so.4 )
( cd usr/lib ; ln -sf libakonadi-calendar.so.4.8.0 libakonadi-calendar.so.4 )
( cd usr/lib ; rm -rf libkholidays.so.4 )
( cd usr/lib ; ln -sf libkholidays.so.4.8.0 libkholidays.so.4 )
( cd usr/lib ; rm -rf libkpimutils.so )
( cd usr/lib ; ln -sf libkpimutils.so.4 libkpimutils.so )
( cd usr/lib ; rm -rf libkimap.so )
( cd usr/lib ; ln -sf libkimap.so.4 libkimap.so )
( cd usr/lib ; rm -rf libkxmlrpcclient.so.4 )
( cd usr/lib ; ln -sf libkxmlrpcclient.so.4.8.0 libkxmlrpcclient.so.4 )
( cd usr/lib ; rm -rf libmicroblog.so )
( cd usr/lib ; ln -sf libmicroblog.so.4 libmicroblog.so )
( cd usr/lib ; rm -rf libmailtransport.so )
( cd usr/lib ; ln -sf libmailtransport.so.4 libmailtransport.so )
( cd usr/lib ; rm -rf libakonadi-kabc.so )
( cd usr/lib ; ln -sf libakonadi-kabc.so.4 libakonadi-kabc.so )
( cd usr/lib ; rm -rf libkabc.so )
( cd usr/lib ; ln -sf libkabc.so.4 libkabc.so )
( cd usr/lib ; rm -rf libgpgme++.so.2 )
( cd usr/lib ; ln -sf libgpgme++.so.2.8.0 libgpgme++.so.2 )
( cd usr/lib ; rm -rf libkxmlrpcclient.so )
( cd usr/lib ; ln -sf libkxmlrpcclient.so.4 libkxmlrpcclient.so )
( cd usr/lib ; rm -rf libmailtransport.so.4 )
( cd usr/lib ; ln -sf libmailtransport.so.4.8.0 libmailtransport.so.4 )
( cd usr/lib ; rm -rf libkontactinterface.so )
( cd usr/lib ; ln -sf libkontactinterface.so.4 libkontactinterface.so )
( cd usr/lib ; rm -rf libktnef.so )
( cd usr/lib ; ln -sf libktnef.so.4 libktnef.so )
( cd usr/lib ; rm -rf libkblog.so )
( cd usr/lib ; ln -sf libkblog.so.4 libkblog.so )
( cd usr/lib ; rm -rf libkpimidentities.so.4 )
( cd usr/lib ; ln -sf libkpimidentities.so.4.8.0 libkpimidentities.so.4 )
( cd usr/lib ; rm -rf libkresources.so )
( cd usr/lib ; ln -sf libkresources.so.4 libkresources.so )
( cd usr/lib ; rm -rf libkcal.so )
( cd usr/lib ; ln -sf libkcal.so.4 libkcal.so )
( cd usr/lib ; rm -rf libsyndication.so )
( cd usr/lib ; ln -sf libsyndication.so.4 libsyndication.so )
( cd usr/lib ; rm -rf libakonadi-contact.so )
( cd usr/lib ; ln -sf libakonadi-contact.so.4 libakonadi-contact.so )
( cd usr/lib ; rm -rf libkcalcore.so.4 )
( cd usr/lib ; ln -sf libkcalcore.so.4.8.0 libkcalcore.so.4 )
( cd usr/lib ; rm -rf libkpimtextedit.so )
( cd usr/lib ; ln -sf libkpimtextedit.so.4 libkpimtextedit.so )
( cd usr/lib ; rm -rf libsyndication.so.4 )
( cd usr/lib ; ln -sf libsyndication.so.4.8.0 libsyndication.so.4 )
( cd usr/lib ; rm -rf libkresources.so.4 )
( cd usr/lib ; ln -sf libkresources.so.4.8.0 libkresources.so.4 )
( cd usr/lib ; rm -rf libakonadi-kabc.so.4 )
( cd usr/lib ; ln -sf libakonadi-kabc.so.4.8.0 libakonadi-kabc.so.4 )
( cd usr/lib ; rm -rf libkholidays.so )
( cd usr/lib ; ln -sf libkholidays.so.4 libkholidays.so )
( cd usr/lib ; rm -rf libkmime.so )
( cd usr/lib ; ln -sf libkmime.so.4 libkmime.so )
( cd usr/lib ; rm -rf libakonadi-kmime.so )
( cd usr/lib ; ln -sf libakonadi-kmime.so.4 libakonadi-kmime.so )
( cd usr/lib ; rm -rf libkabc_file_core.so.4 )
( cd usr/lib ; ln -sf libkabc_file_core.so.4.8.0 libkabc_file_core.so.4 )
( cd usr/lib ; rm -rf libkcal.so.4 )
( cd usr/lib ; ln -sf libkcal.so.4.8.0 libkcal.so.4 )
( cd usr/lib ; rm -rf libkpimutils.so.4 )
( cd usr/lib ; ln -sf libkpimutils.so.4.8.0 libkpimutils.so.4 )
( cd usr/lib ; rm -rf libakonadi-kde.so )
( cd usr/lib ; ln -sf libakonadi-kde.so.4 libakonadi-kde.so )
( cd usr/lib ; rm -rf libkmime.so.4 )
( cd usr/lib ; ln -sf libkmime.so.4.8.0 libkmime.so.4 )
( cd usr/lib ; rm -rf libkabc.so.4 )
( cd usr/lib ; ln -sf libkabc.so.4.8.0 libkabc.so.4 )
( cd usr/lib ; rm -rf libgpgme++-pthread.so.2 )
( cd usr/lib ; ln -sf libgpgme++-pthread.so.2.8.0 libgpgme++-pthread.so.2 )
( cd usr/lib ; rm -rf libkmbox.so.4 )
( cd usr/lib ; ln -sf libkmbox.so.4.8.0 libkmbox.so.4 )
( cd usr/lib ; rm -rf libakonadi-notes.so )
( cd usr/lib ; ln -sf libakonadi-notes.so.4 libakonadi-notes.so )
( cd usr/lib ; rm -rf libakonadi-kcal.so.4 )
( cd usr/lib ; ln -sf libakonadi-kcal.so.4.8.0 libakonadi-kcal.so.4 )
( cd usr/lib ; rm -rf libgpgme++-pthread.so )
( cd usr/lib ; ln -sf libgpgme++-pthread.so.2 libgpgme++-pthread.so )
( cd usr/lib ; rm -rf libakonadi-notes.so.4 )
( cd usr/lib ; ln -sf libakonadi-notes.so.4.8.0 libakonadi-notes.so.4 )
( cd usr/lib ; rm -rf libkmbox.so )
( cd usr/lib ; ln -sf libkmbox.so.4 libkmbox.so )
( cd usr/lib ; rm -rf libkcalcore.so )
( cd usr/lib ; ln -sf libkcalcore.so.4 libkcalcore.so )
( cd usr/lib ; rm -rf libkalarmcal.so.2 )
( cd usr/lib ; ln -sf libkalarmcal.so.2.7.0 libkalarmcal.so.2 )
( cd usr/lib ; rm -rf libkpimidentities.so )
( cd usr/lib ; ln -sf libkpimidentities.so.4 libkpimidentities.so )
( cd usr/lib ; rm -rf libkcalutils.so.4 )
( cd usr/lib ; ln -sf libkcalutils.so.4.8.0 libkcalutils.so.4 )
( cd usr/lib ; rm -rf libqgpgme.so.1 )
( cd usr/lib ; ln -sf libqgpgme.so.1.0.1 libqgpgme.so.1 )
( cd usr/lib ; rm -rf libkontactinterface.so.4 )
( cd usr/lib ; ln -sf libkontactinterface.so.4.8.0 libkontactinterface.so.4 )
( cd usr/lib ; rm -rf libkldap.so.4 )
( cd usr/lib ; ln -sf libkldap.so.4.8.0 libkldap.so.4 )
( cd usr/lib ; rm -rf libkldap.so )
( cd usr/lib ; ln -sf libkldap.so.4 libkldap.so )
( cd usr/lib ; rm -rf libakonadi-kcal.so )
( cd usr/lib ; ln -sf libakonadi-kcal.so.4 libakonadi-kcal.so )
( cd usr/doc/HTML/en/kcontrol/kresources ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/kresources ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/ldap ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/ldap ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/pop3 ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/pop3 ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/mbox ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/mbox ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/imap ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/imap ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/smtp ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/smtp ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/sieve ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/sieve ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/nntp ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/nntp ; ln -sf /usr/share/doc/HTML/en/common common )

==> kdepimlibs-4.10.5-i486-1.txz: install/doinst.sh <==
( cd usr/lib ; rm -rf libmicroblog.so.4 )
( cd usr/lib ; ln -sf libmicroblog.so.4.10.5 libmicroblog.so.4 )
( cd usr/lib ; rm -rf libktnef.so.4 )
( cd usr/lib ; ln -sf libktnef.so.4.10.5 libktnef.so.4 )
( cd usr/lib ; rm -rf libkalarmcal.so )
( cd usr/lib ; ln -sf libkalarmcal.so.2 libkalarmcal.so )
( cd usr/lib ; rm -rf libqgpgme.so )
( cd usr/lib ; ln -sf libqgpgme.so.1 libqgpgme.so )
( cd usr/lib ; rm -rf libkimap.so.4 )
( cd usr/lib ; ln -sf libkimap.so.4.10.5 libkimap.so.4 )
( cd usr/lib ; rm -rf libakonadi-kmime.so.4 )
( cd usr/lib ; ln -sf libakonadi-kmime.so.4.10.5 libakonadi-kmime.so.4 )
( cd usr/lib ; rm -rf libkblog.so.4 )
( cd usr/lib ; ln -sf libkblog.so.4.10.5 libkblog.so.4 )
( cd usr/lib ; rm -rf libakonadi-kde.so.4 )
( cd usr/lib ; ln -sf libakonadi-kde.so.4.10.5 libakonadi-kde.so.4 )
( cd usr/lib ; rm -rf libakonadi-calendar.so )
( cd usr/lib ; ln -sf libakonadi-calendar.so.4 libakonadi-calendar.so )
( cd usr/lib ; rm -rf libakonadi-contact.so.4 )
( cd usr/lib ; ln -sf libakonadi-contact.so.4.10.5 libakonadi-contact.so.4 )
( cd usr/lib ; rm -rf libkpimtextedit.so.4 )
( cd usr/lib ; ln -sf libkpimtextedit.so.4.10.5 libkpimtextedit.so.4 )
( cd usr/lib ; rm -rf libgpgme++.so )
( cd usr/lib ; ln -sf libgpgme++.so.2 libgpgme++.so )
( cd usr/lib ; rm -rf libkabc_file_core.so )
( cd usr/lib ; ln -sf libkabc_file_core.so.4 libkabc_file_core.so )
( cd usr/lib ; rm -rf libkcalutils.so )
( cd usr/lib ; ln -sf libkcalutils.so.4 libkcalutils.so )
( cd usr/lib ; rm -rf libakonadi-calendar.so.4 )
( cd usr/lib ; ln -sf libakonadi-calendar.so.4.10.5 libakonadi-calendar.so.4 )
( cd usr/lib ; rm -rf libkholidays.so.4 )
( cd usr/lib ; ln -sf libkholidays.so.4.10.5 libkholidays.so.4 )
( cd usr/lib ; rm -rf libkpimutils.so )
( cd usr/lib ; ln -sf libkpimutils.so.4 libkpimutils.so )
( cd usr/lib ; rm -rf libkimap.so )
( cd usr/lib ; ln -sf libkimap.so.4 libkimap.so )
( cd usr/lib ; rm -rf libakonadi-socialutils.so.4 )
( cd usr/lib ; ln -sf libakonadi-socialutils.so.4.10.5 libakonadi-socialutils.so.4 )
( cd usr/lib ; rm -rf libkxmlrpcclient.so.4 )
( cd usr/lib ; ln -sf libkxmlrpcclient.so.4.10.5 libkxmlrpcclient.so.4 )
( cd usr/lib ; rm -rf libmicroblog.so )
( cd usr/lib ; ln -sf libmicroblog.so.4 libmicroblog.so )
( cd usr/lib ; rm -rf libmailtransport.so )
( cd usr/lib ; ln -sf libmailtransport.so.4 libmailtransport.so )
( cd usr/lib ; rm -rf libakonadi-kabc.so )
( cd usr/lib ; ln -sf libakonadi-kabc.so.4 libakonadi-kabc.so )
( cd usr/lib ; rm -rf libkabc.so )
( cd usr/lib ; ln -sf libkabc.so.4 libkabc.so )
( cd usr/lib ; rm -rf libgpgme++.so.2 )
( cd usr/lib ; ln -sf libgpgme++.so.2.8.0 libgpgme++.so.2 )
( cd usr/lib ; rm -rf libkxmlrpcclient.so )
( cd usr/lib ; ln -sf libkxmlrpcclient.so.4 libkxmlrpcclient.so )
( cd usr/lib ; rm -rf libmailtransport.so.4 )
( cd usr/lib ; ln -sf libmailtransport.so.4.10.5 libmailtransport.so.4 )
( cd usr/lib ; rm -rf libkontactinterface.so )
( cd usr/lib ; ln -sf libkontactinterface.so.4 libkontactinterface.so )
( cd usr/lib ; rm -rf libktnef.so )
( cd usr/lib ; ln -sf libktnef.so.4 libktnef.so )
( cd usr/lib ; rm -rf libkblog.so )
( cd usr/lib ; ln -sf libkblog.so.4 libkblog.so )
( cd usr/lib ; rm -rf libkpimidentities.so.4 )
( cd usr/lib ; ln -sf libkpimidentities.so.4.10.5 libkpimidentities.so.4 )
( cd usr/lib ; rm -rf libkresources.so )
( cd usr/lib ; ln -sf libkresources.so.4 libkresources.so )
( cd usr/lib ; rm -rf libkcal.so )
( cd usr/lib ; ln -sf libkcal.so.4 libkcal.so )
( cd usr/lib ; rm -rf libsyndication.so )
( cd usr/lib ; ln -sf libsyndication.so.4 libsyndication.so )
( cd usr/lib ; rm -rf libakonadi-contact.so )
( cd usr/lib ; ln -sf libakonadi-contact.so.4 libakonadi-contact.so )
( cd usr/lib ; rm -rf libkcalcore.so.4 )
( cd usr/lib ; ln -sf libkcalcore.so.4.10.5 libkcalcore.so.4 )
( cd usr/lib ; rm -rf libkpimtextedit.so )
( cd usr/lib ; ln -sf libkpimtextedit.so.4 libkpimtextedit.so )
( cd usr/lib ; rm -rf libsyndication.so.4 )
( cd usr/lib ; ln -sf libsyndication.so.4.10.5 libsyndication.so.4 )
( cd usr/lib ; rm -rf libkresources.so.4 )
( cd usr/lib ; ln -sf libkresources.so.4.10.5 libkresources.so.4 )
( cd usr/lib ; rm -rf libakonadi-kabc.so.4 )
( cd usr/lib ; ln -sf libakonadi-kabc.so.4.10.5 libakonadi-kabc.so.4 )
( cd usr/lib ; rm -rf libkholidays.so )
( cd usr/lib ; ln -sf libkholidays.so.4 libkholidays.so )
( cd usr/lib ; rm -rf libkmime.so )
( cd usr/lib ; ln -sf libkmime.so.4 libkmime.so )
( cd usr/lib ; rm -rf libakonadi-kmime.so )
( cd usr/lib ; ln -sf libakonadi-kmime.so.4 libakonadi-kmime.so )
( cd usr/lib ; rm -rf libkabc_file_core.so.4 )
( cd usr/lib ; ln -sf libkabc_file_core.so.4.10.5 libkabc_file_core.so.4 )
( cd usr/lib ; rm -rf libkcal.so.4 )
( cd usr/lib ; ln -sf libkcal.so.4.10.5 libkcal.so.4 )
( cd usr/lib ; rm -rf libkpimutils.so.4 )
( cd usr/lib ; ln -sf libkpimutils.so.4.10.5 libkpimutils.so.4 )
( cd usr/lib ; rm -rf libakonadi-kde.so )
( cd usr/lib ; ln -sf libakonadi-kde.so.4 libakonadi-kde.so )
( cd usr/lib ; rm -rf libkmime.so.4 )
( cd usr/lib ; ln -sf libkmime.so.4.10.5 libkmime.so.4 )
( cd usr/lib ; rm -rf libkabc.so.4 )
( cd usr/lib ; ln -sf libkabc.so.4.10.5 libkabc.so.4 )
( cd usr/lib ; rm -rf libgpgme++-pthread.so.2 )
( cd usr/lib ; ln -sf libgpgme++-pthread.so.2.8.0 libgpgme++-pthread.so.2 )
( cd usr/lib ; rm -rf libkmbox.so.4 )
( cd usr/lib ; ln -sf libkmbox.so.4.10.5 libkmbox.so.4 )
( cd usr/lib ; rm -rf libakonadi-notes.so )
( cd usr/lib ; ln -sf libakonadi-notes.so.4 libakonadi-notes.so )
( cd usr/lib ; rm -rf libakonadi-kcal.so.4 )
( cd usr/lib ; ln -sf libakonadi-kcal.so.4.10.5 libakonadi-kcal.so.4 )
( cd usr/lib ; rm -rf libgpgme++-pthread.so )
( cd usr/lib ; ln -sf libgpgme++-pthread.so.2 libgpgme++-pthread.so )
( cd usr/lib ; rm -rf libakonadi-notes.so.4 )
( cd usr/lib ; ln -sf libakonadi-notes.so.4.10.5 libakonadi-notes.so.4 )
( cd usr/lib ; rm -rf libakonadi-socialutils.so )
( cd usr/lib ; ln -sf libakonadi-socialutils.so.4 libakonadi-socialutils.so )
( cd usr/lib ; rm -rf libkmbox.so )
( cd usr/lib ; ln -sf libkmbox.so.4 libkmbox.so )
( cd usr/lib ; rm -rf libkcalcore.so )
( cd usr/lib ; ln -sf libkcalcore.so.4 libkcalcore.so )
( cd usr/lib ; rm -rf libkalarmcal.so.2 )
( cd usr/lib ; ln -sf libkalarmcal.so.2.7.0 libkalarmcal.so.2 )
( cd usr/lib ; rm -rf libkpimidentities.so )
( cd usr/lib ; ln -sf libkpimidentities.so.4 libkpimidentities.so )
( cd usr/lib ; rm -rf libkcalutils.so.4 )
( cd usr/lib ; ln -sf libkcalutils.so.4.10.5 libkcalutils.so.4 )
( cd usr/lib ; rm -rf libqgpgme.so.1 )
( cd usr/lib ; ln -sf libqgpgme.so.1.0.1 libqgpgme.so.1 )
( cd usr/lib ; rm -rf libkontactinterface.so.4 )
( cd usr/lib ; ln -sf libkontactinterface.so.4.10.5 libkontactinterface.so.4 )
( cd usr/lib ; rm -rf libkldap.so.4 )
( cd usr/lib ; ln -sf libkldap.so.4.10.5 libkldap.so.4 )
( cd usr/lib ; rm -rf libkldap.so )
( cd usr/lib ; ln -sf libkldap.so.4 libkldap.so )
( cd usr/lib ; rm -rf libakonadi-kcal.so )
( cd usr/lib ; ln -sf libakonadi-kcal.so.4 libakonadi-kcal.so )
( cd usr/doc/HTML/en/kcontrol/kresources ; rm -rf common )
( cd usr/doc/HTML/en/kcontrol/kresources ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/ldap ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/ldap ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/pop3 ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/pop3 ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/mbox ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/mbox ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/imap ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/imap ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/smtp ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/smtp ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/sieve ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/sieve ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/doc/HTML/en/kioslave/nntp ; rm -rf common )
( cd usr/doc/HTML/en/kioslave/nntp ; ln -sf /usr/share/doc/HTML/en/common common )
